﻿using Microsoft.Extensions.Logging;
using SewingDressesContracts.BindingModels;
using SewingDressesContracts.BusinessLogicsContracts;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SewingDressesView
{
	public partial class ClientsForm : Form
	{
		private readonly ILogger _logger;
		private readonly IClientLogic _clientLogic;

		public ClientsForm(ILogger<ClientsForm> logger, IClientLogic clientLogic)
		{
			InitializeComponent();
			_logger = logger;
			_clientLogic = clientLogic;
			LoadData();
		}

		private void buttonDelete_Click(object sender, EventArgs e)
		{
			if (dataGridView.SelectedRows.Count == 1)
			{
				if (MessageBox.Show("Удалить запись?", "Вопрос", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
				{
					int id = Convert.ToInt32(dataGridView.SelectedRows[0].Cells["Id"].Value);
					_logger.LogInformation("Delete client");
					try
					{
						if (!_clientLogic.Delete(new ClientBindingModel
						{
							Id = id
						}))
						{
							throw new Exception("Ошибка при удалении. Дополнительная информация в логах.");
						}
						LoadData();
					}
					catch (Exception ex)
					{
						_logger.LogError(ex, "Delete client error");
						MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
					}
				}
			}

		}
		private void LoadData()
		{
			try
			{
				var list = _clientLogic.ReadList(null);
				if (list != null)
				{
					dataGridView.DataSource = list;
					dataGridView.Columns["Id"].Visible = false;
					dataGridView.Columns["ClientFIO"].AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
					dataGridView.Columns["Password"].Visible = false;
				}
				_logger.LogInformation("Load clients");
			}
			catch (Exception ex)
			{
				_logger.LogError(ex, "Load clients error");
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		private void buttonUpdate_Click(object sender, EventArgs e)
		{
			LoadData();
		}
	}
}
