using SewingDressesBusinessLogic.BusinessLogic;
using SewingDressesContracts.BusinessLogicsContracts;
using SewingDressesContracts.StoragesContracts;
using SewingDressesDatabaseImplement.Implements;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using NLog.Extensions.Logging;
using System.Drawing;
using SewingDressesBusinessLogic.OfficePackage;
using SewingDressesBusinessLogic.OfficePackage.Implements;
using SewingDressesBusinessLogic.MailWorker;

namespace SewingDressesView
{
    internal static class Program
    {
        private static ServiceProvider? _serviceProvider;
        public static ServiceProvider? ServiceProvider => _serviceProvider;
        [STAThread]
        static void Main()
        {
            ApplicationConfiguration.Initialize();
            var services = new ServiceCollection();
            ConfigureServices(services);
            _serviceProvider = services.BuildServiceProvider();
            try
            {
                var mailSender = _serviceProvider.GetService<AbstractMailWorker>();
                mailSender?.MailConfig(new()
                {
                    MailLogin = System.Configuration.ConfigurationManager.AppSettings["MailLogin"] ?? string.Empty,
					MailPassword = System.Configuration.ConfigurationManager.AppSettings["MailPassword"] ?? string.Empty,
					SmtpClientHost = System.Configuration.ConfigurationManager.AppSettings["SmtpClientHost"] ?? string.Empty,
					SmtpClientPort = Convert.ToInt32(System.Configuration.ConfigurationManager.AppSettings["SmtpClientPort"]),
                    PopHost = System.Configuration.ConfigurationManager.AppSettings["PopHost"] ?? string.Empty,
                    PopPort = Convert.ToInt32(System.Configuration.ConfigurationManager.AppSettings["PopPort"])
				});
                var timer = new System.Threading.Timer(new TimerCallback(MailCheck!), null, 0, 100000);
            }
            catch (Exception ex)
            {
				var logger = _serviceProvider.GetService<ILogger>();
				logger?.LogError(ex, "   ");
			}
            Application.Run(_serviceProvider.GetRequiredService<MainForm>());
        }
        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddLogging(option =>
            {
                option.SetMinimumLevel(LogLevel.Information);
                option.AddNLog("nlog.config");
            });
            services.AddTransient<IComponentStorage, ComponentStorage>();
            services.AddTransient<IOrderStorage, OrderStorage>();
            services.AddTransient<IDressStorage, DressStorage>();
            services.AddTransient<IClientStorage, ClientStorage>();
            services.AddTransient<IComponentLogic, ComponentLogic>();
            services.AddTransient<IOrderLogic, OrderLogic>();
            services.AddTransient<IDressLogic, DressLogic>();
            services.AddTransient<IReportLogic, ReportLogic>();
            services.AddTransient<IClientLogic, ClientLogic>();
            services.AddTransient<IImplementLogic, ImplementLogic>();
            services.AddTransient<IImplementStorage, ImplementStorage>();
            services.AddTransient<IWorkProcess, WorkModeling>();
            services.AddTransient<IMessageInfoStorage, MessageInfoStorage>();
            services.AddTransient<IMessageInfoLogic, MessageInfoLogic>();
            services.AddTransient<AbstractMailWorker, MailKitWorker>();
            services.AddTransient<AbstractSaveToExcel, SaveToExcel>();
            services.AddTransient<AbstractSaveToPdf, SaveToPdf>();
            services.AddTransient<AbstractSaveToWord, SaveToWord>();
            services.AddTransient<MainForm>();
            services.AddTransient<ComponentForm>();
            services.AddTransient<ComponentsForm>();
            services.AddTransient<OrderForm>();
            services.AddTransient<DressForm>();
            services.AddTransient<DressComponentForm>();
            services.AddTransient<ClientsForm>();
            services.AddTransient<DressesForm>();
            services.AddTransient<ReportDressComponentsForm>();
            services.AddTransient<ReportOrdersForm>();
            services.AddTransient<ImplementForm>();
            services.AddTransient<ImplementsForm>();
            services.AddTransient<MailForm>();
        }
		private static void MailCheck(object obj) => ServiceProvider?.GetService<AbstractMailWorker>()?.MailCheck();
	}
}